pub struct ModuleToTokensConfig {
pub structs_filter: Option<HashSet<String>>,
pub gen_glam: bool,
pub gen_encase: bool,
pub gen_naga: bool,
}Expand description
The configuration required to create a token stream describing a module.
Fields
structs_filter: Option<HashSet<String>>A filter on the structs to expose. This is useful specifically when using the encase feature,
since many structs can’t be encoded or decoded. It is therefore the using crate’s responsibility
to expose this in some way, for example by having structs that should be exported to Rust require
an attribute.
gen_glam: boolGenerate glam types.
gen_encase: boolGenerate encase types.
gen_naga: boolGenerate naga types.